@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1999, 2000 Florian Schintke
+  Copyright (C) 1999 - 2006 Florian Schintke
   Copyright (C) 1999       Martin Kammerhofer for the CGI feature
   Copyright (C) 2000       Rob Ewan           for the indexing feature
 
@@ -107,6 +107,8 @@ MyMain(int argc, char *argv[])
 	      continue;
 	    }
 	  outfilename = malloc (sizeof (char)*strlen (argv[i]) + 6);
+	  if (NULL == outfilename)
+	    { fprintf (stderr, "Cannot allocate enough memory.\n"); }
 	  strcat (strcpy (outfilename, argv[i]), ".html");
 	  actout = fopen (outfilename, "w");
 	  if (!actout) 
@@ -165,7 +167,7 @@ PrintUsage()
   fprintf (stderr, "  -V       print version information\n");
   fprintf (stderr, "  -u       print this usage information\n");
   fprintf (stderr, "  -t title set HTML title\n");
-  fprintf (stderr, "  -w width use width for output (default 80)\n");
+  fprintf (stderr, "  -w width use width for output (default 80), 0 to disable\n");
   fprintf (stderr, "  -x size  use size for tab size (default 8, max 80)\n");
   fprintf (stderr, "  -h file  insert file at the head of converted data\n");
   fprintf (stderr, "  -b file  insert file at the bottom of converted data\n");
@@ -188,7 +190,7 @@ PrintConfig(FILE * output)
 	   config.noheaders ? "on" : "off");  
   fprintf (output, "  linelabeling: %s\n", 
 	   config.linelabeling ? "on" : "off");  
-  fprintf (output, "  skipblanks: %s\n",
+  fprintf (output, "  skipblanks  : %s\n",
 	   config.skipblanks ? "on" : "off");
   fprintf (output, "  width       : %d\n", 
 	   config.width);  
@@ -381,7 +383,10 @@ ConvertFile(char * name)
     }
 
   Insert (actout, config.headfile);
-  fprintf (actout, "<pre width=\"%d\">", config.width);  
+  if (0 < config.width)
+    { fprintf (actout, "<pre width=\"%d\">", config.width); }
+  else
+    { fprintf (actout, "<pre>"); }
   StartNewYylex(actin, actout);
   
   fprintf (actout, "</pre>\n");
